#ifndef NT2_INCLUDE_FUNCTIONS_DIST_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DIST_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/dist.hpp>

#endif
